@@ -169,7 +169,7 @@ static GConfMetaInfo*query_metainfo  (GConfSource* source,
 
 static void          set_value       (GConfSource* source,
                                       const gchar* key,
-                                      GConfValue* value,
+                                      const GConfValue* value,
                                       GError** err);
 
 static GSList*       all_entries    (GConfSource* source,
@@ -230,7 +230,7 @@ static GConfBackendVTable xml_vtable = {
 static void          
 x_shutdown (GError** err)
 {
-  gconf_log(GCL_DEBUG, _("Unloading XML backend module."));
+  gconf_log(GCL_INFO, _("Unloading XML backend module."));
 }
 
 static void
@@ -278,9 +278,6 @@ resolve_address (const gchar* address, GError** err)
   GConfLock* lock = NULL;
   guint dir_mode = 0700;
   guint file_mode = 0600;
-  gchar** address_flags;
-  gchar** iter;
-  gboolean force_readonly;
   
   root_dir = gconf_address_resource(address);
 
@@ -318,51 +315,26 @@ resolve_address (const gchar* address, GError** err)
             }
         }
     }
-
-  force_readonly = FALSE;
   
-  address_flags = gconf_address_flags (address);  
-  if (address_flags)
-    {
-      iter = address_flags;
-      while (*iter)
-        {
-          if (strcmp (*iter, "readonly") == 0)
-            {
-              force_readonly = TRUE;
-              break;
-            }
-
-          ++iter;
-        }
-    }
-
-  g_strfreev (address_flags);
-
   {
     /* See if we're writable */
-    gboolean writable;
+    gboolean writable = FALSE;
     int fd;
     gchar* testfile;
 
-    writable = FALSE;
+    testfile = g_strconcat(root_dir, "/.testing.writeability", NULL);    
     
-    if (!force_readonly)
+    fd = open(testfile, O_CREAT|O_WRONLY, S_IRWXU);
+
+    if (fd >= 0)
       {
-        testfile = g_strconcat(root_dir, "/.testing.writeability", NULL);    
-        
-        fd = open(testfile, O_CREAT|O_WRONLY, S_IRWXU);
-        
-        if (fd >= 0)
-          {
-            writable = TRUE;
-            close(fd);
-          }
-        
-        unlink(testfile);
-        
-        g_free(testfile);
+        writable = TRUE;
+        close(fd);
       }
+        
+    unlink(testfile);
+
+    g_free(testfile);
     
     if (writable)
       flags |= GCONF_SOURCE_ALL_WRITEABLE;
@@ -420,7 +392,7 @@ resolve_address (const gchar* address, GError** err)
 
   xsource = xs_new(root_dir, dir_mode, file_mode, lock);
 
-  gconf_log(GCL_DEBUG,
+  gconf_log(GCL_INFO,
             _("Directory/file permissions for XML source at root %s are: %o/%o"),
             root_dir, dir_mode, file_mode);
   
@@ -457,7 +429,7 @@ query_value (GConfSource* source,
      problem, since some errors may be added that need reporting. */
   if (error != NULL)
     {
-      gconf_log(GCL_WARNING, "%s", error->message);
+      gconf_log(GCL_WARNING, error->message);
       g_error_free(error);
       error = NULL;
     }
@@ -477,7 +449,7 @@ query_value (GConfSource* source,
       /* perhaps we should be reporting this error... */
       if (error != NULL)
         {
-          gconf_log(GCL_WARNING, "%s", error->message);
+          gconf_log(GCL_WARNING, error->message);
           g_error_free(error);
           error = NULL;
         }
@@ -513,7 +485,7 @@ query_metainfo  (GConfSource* source, const gchar* key,
 }
 
 static void          
-set_value (GConfSource* source, const gchar* key, GConfValue* value,
+set_value (GConfSource* source, const gchar* key, const GConfValue* value,
            GError** err)
 {
   XMLSource* xs = (XMLSource*)source;
@@ -705,7 +677,10 @@ clear_cache     (GConfSource* source)
 G_MODULE_EXPORT const gchar*
 g_module_check_init (GModule *module)
 {
-  gconf_log(GCL_DEBUG, _("Initializing XML backend module"));
+  gconf_log(GCL_INFO, _("Initializing XML backend module"));
+
+  LIBXML_TEST_VERSION;
+  xmlKeepBlanksDefault(1);
 
   return NULL;
 }
