@@ -418,7 +418,7 @@ dir_sync        (Dir* d, GError** err)
 
 void
 dir_set_value   (Dir* d, const gchar* relative_key,
-                 GConfValue* value, GError** err)
+                 const GConfValue* value, GError** err)
 {
   Entry* e;
   
@@ -487,9 +487,12 @@ dir_get_value   (Dir* d,
 
       val = entry_get_value (e, locales, err);
 
-      /* Get schema name if requested */
-      if (schema_name && entry_get_schema_name (e))
-        *schema_name = g_strdup (entry_get_schema_name (e));
+      /* Fill schema name if value is NULL because we might be
+         interested in the default value of the key in that case. */
+      if (schema_name &&
+          val == NULL &&
+          entry_get_schema_name(e))
+        *schema_name = g_strdup(entry_get_schema_name(e));
       
       /* return copy of the value */
       if (val != NULL)
@@ -835,16 +838,16 @@ dir_load_doc(Dir* d, GError** err)
       d->doc = xmlNewDoc("1.0");
     }
   
-  if (d->doc->root == NULL)
+  if (d->doc->xmlRootNode == NULL)
     {
       /* fill it in */
-      d->doc->root = xmlNewDocNode(d->doc, NULL, "gconf", NULL);
+      d->doc->xmlRootNode = xmlNewDocNode(d->doc, NULL, "gconf", NULL);
     }
-  else if (strcmp(d->doc->root->name, "gconf") != 0)
+  else if (strcmp(d->doc->xmlRootNode->name, "gconf") != 0)
     {
       xmlFreeDoc(d->doc);
       d->doc = xmlNewDoc("1.0");
-      d->doc->root = xmlNewDocNode(d->doc, NULL, "gconf", NULL);
+      d->doc->xmlRootNode = xmlNewDocNode(d->doc, NULL, "gconf", NULL);
       need_backup = TRUE; /* save broken stuff */
     }
   else
@@ -877,7 +880,7 @@ dir_load_doc(Dir* d, GError** err)
     }
   
   g_assert(d->doc != NULL);
-  g_assert(d->doc->root != NULL);
+  g_assert(d->doc->xmlRootNode != NULL);
 }
 
 static Entry*
@@ -886,11 +889,11 @@ dir_make_new_entry(Dir* d, const gchar* relative_key)
   Entry* e;
 
   g_return_val_if_fail(d->doc != NULL, NULL);
-  g_return_val_if_fail(d->doc->root != NULL, NULL);
+  g_return_val_if_fail(d->doc->xmlRootNode != NULL, NULL);
   
   e = entry_new(relative_key);
 
-  entry_set_node(e, xmlNewChild(d->doc->root, NULL, "entry", NULL));
+  entry_set_node(e, xmlNewChild(d->doc->xmlRootNode, NULL, "entry", NULL));
   
   safe_g_hash_table_insert(d->entry_cache, (gchar*)entry_get_name(e), e);
   
@@ -923,14 +926,14 @@ dir_fill_cache_from_doc(Dir* d)
   xmlNodePtr node;
   
   if (d->doc == NULL ||
-      d->doc->root == NULL ||
-      d->doc->root->childs == NULL)
+      d->doc->xmlRootNode == NULL ||
+      d->doc->xmlRootNode->xmlChildrenNode == NULL)
     {
       /* Empty document - just return. */
       return;
     }
 
-  node = d->doc->root->childs;
+  node = d->doc->xmlRootNode->xmlChildrenNode;
 
   while (node != NULL)
     {
@@ -972,11 +975,9 @@ dir_fill_cache_from_doc(Dir* d)
         }
       else
         {
-          if (node->type == XML_ELEMENT_NODE)
-            gconf_log(GCL_WARNING,
-                      _("A toplevel node in XML file `%s' is <%s> rather than <entry>, ignoring"),
-                      d->xml_filename,
-                      node->name ? (char*) node->name : "unknown");
+          gconf_log(GCL_WARNING,
+                     _("Toplevel node in XML file `%s' is not an <entry>, ignoring"),
+                     d->xml_filename);
         }
       
       node = node->next;
