@@ -20,11 +20,12 @@
 #include "xml-entry.h"
 #include <gconf/gconf-internals.h>
 #include <stdlib.h>
+#include <string.h>
 #include <libxml/entities.h>
 #include <libxml/xmlmemory.h>
 
 static void
-entry_sync_if_needed(Entry* e, GConfValue* val);
+entry_sync_if_needed(Entry* e);
 static GConfValue*
 node_extract_value(xmlNodePtr node, const gchar** locales, GError** err);
 static xmlNodePtr
@@ -133,7 +134,7 @@ entry_get_value(Entry* e, const gchar** locales, GError** err)
       GConfValue* newval;
       GError* error = NULL;
 
-      entry_sync_if_needed(e, NULL);
+      entry_sync_if_needed(e);
       
       newval = node_extract_value(e->node, locales, &error);
       if (newval != NULL)
@@ -159,11 +160,11 @@ entry_get_value(Entry* e, const gchar** locales, GError** err)
 }
 
 void
-entry_set_value(Entry* e, GConfValue* value)
+entry_set_value(Entry* e, const GConfValue* value)
 {
   g_return_if_fail(e != NULL);
 
-  entry_sync_if_needed(e, value);
+  entry_sync_if_needed(e);
   
   if (e->cached_value)
     gconf_value_free(e->cached_value);
@@ -197,7 +198,7 @@ entry_unset_value     (Entry        *e,
 
           if (error != NULL)
             {
-              gconf_log(GCL_WARNING, "%s", error->message);
+              gconf_log(GCL_WARNING, _("%s"), error->message);
               g_error_free(error);
               error = NULL;
             }
@@ -290,7 +291,7 @@ entry_set_mod_user (Entry *e,
  */
 
 static void
-entry_sync_if_needed(Entry* e, GConfValue* val)
+entry_sync_if_needed(Entry* e)
 {
   if (!e->dirty)
     return;
@@ -352,7 +353,7 @@ entry_fill_from_node(Entry* e)
   else
     e->mod_user = NULL;
 
-  entry_sync_if_needed(e, NULL);
+  entry_sync_if_needed(e);
   
   if (e->cached_value != NULL)
     gconf_value_free(e->cached_value);
@@ -367,13 +368,11 @@ entry_fill_from_node(Entry* e)
     }
   else if (error != NULL)
     {
-      /* Ignore errors from node_extract_value() if we got a schema name,
-       * since the node's only purpose may be to store the schema name.
+      /* FIXME for nodes with no value stored, but containing a schema name,
+       * we improperly log an error here
        */
-      if (e->schema_name == NULL)
-        gconf_log (GCL_WARNING,
-                   _("Ignoring XML node `%s': %s"),
-                   e->name, error->message);
+      gconf_log(GCL_WARNING, _("Ignoring XML node `%s', except for possible schema name: %s"),
+                e->name, error->message);
       g_error_free(error);
     }
 }
@@ -386,9 +385,9 @@ free_childs(xmlNodePtr node)
 {
   g_return_if_fail(node != NULL);
   
-  if (node->childs)
-    xmlFreeNodeList(node->childs);
-  node->childs = NULL;
+  if (node->xmlChildrenNode)
+    xmlFreeNodeList(node->xmlChildrenNode);
+  node->xmlChildrenNode = NULL;
   node->last = NULL;
 }
 
@@ -607,7 +606,7 @@ find_schema_subnode_by_locale(xmlNodePtr node, const gchar* locale)
   xmlNodePtr iter;
   xmlNodePtr found = NULL;
     
-  iter = node->childs;
+  iter = node->xmlChildrenNode;
       
   while (iter != NULL)
     {
@@ -703,12 +702,12 @@ schema_subnode_extract_data(xmlNodePtr node, GConfSchema* sc)
       gconf_log(GCL_DEBUG, "found <local_schema> with no locale setting");
     }
   
-  if (node->childs != NULL)
+  if (node->xmlChildrenNode != NULL)
     {
       GConfValue* default_value = NULL;
       gchar* ld_str = NULL;
       GSList* bad_nodes = NULL;
-      xmlNodePtr iter = node->childs;
+      xmlNodePtr iter = node->xmlChildrenNode;
 
       while (iter != NULL)
         {
@@ -846,7 +845,7 @@ schema_node_extract_value(xmlNodePtr node, const gchar** locales)
       localized_nodes = g_new0(xmlNodePtr, i+2);
       
       /* Find the node for each possible locale */
-      iter = node->childs;
+      iter = node->xmlChildrenNode;
       
       while (iter != NULL)
         {
@@ -902,7 +901,7 @@ schema_node_extract_value(xmlNodePtr node, const gchar** locales)
     best = find_schema_subnode_by_locale (node, NULL);
 
   if (best == NULL)
-    best = node->childs;
+    best = node->xmlChildrenNode;
   
   /* Extract info from the best locale node */
   if (best != NULL)
@@ -986,7 +985,7 @@ node_extract_value(xmlNodePtr node, const gchar** locales, GError** err)
       {
         xmlNodePtr iter;
         
-        iter = node->childs;
+        iter = node->xmlChildrenNode;
 
         while (iter != NULL)
           {
@@ -1055,7 +1054,7 @@ node_extract_value(xmlNodePtr node, const gchar** locales, GError** err)
             break;
           }
         
-        iter = node->childs;
+        iter = node->xmlChildrenNode;
 
         while (iter != NULL)
           {
@@ -1117,7 +1116,7 @@ node_extract_value(xmlNodePtr node, const gchar** locales, GError** err)
         GConfValue* cdr = NULL;
         xmlNodePtr iter;
         
-        iter = node->childs;
+        iter = node->xmlChildrenNode;
 
         while (iter != NULL)
           {
