@@ -27,9 +27,10 @@
    model; and the prefs dialog is a "controller."
 */
 
-/* Throughout, this program is letting GConfClient use its default error handlers
-   rather than checking for errors or attaching custom handlers to the
-   "unreturned_error" signal. Thus the last arg to GConfClient functions is NULL.
+/* Throughout, this program is letting GConfClient use its default
+   error handlers rather than checking for errors or attaching custom
+   handlers to the "unreturned_error" signal. Thus the last arg to
+   GConfClient functions is NULL.
 */
 
 /* A word about Apply/Revert/OK/Cancel. These should work as follows:
@@ -50,7 +51,7 @@ static GtkWidget* create_prefs_dialog(GtkWidget* parent, GConfClient* client);
 int
 main(int argc, char** argv)
 {
-  GConfError* error = NULL;
+  GError* error = NULL;
   GConfClient* client = NULL;
   GtkWidget* main_window;
   
@@ -61,10 +62,10 @@ main(int argc, char** argv)
   if (!gconf_init(argc, argv, &error))
     {
       g_assert(error != NULL);
-      g_warning("GConf init failed:\n  %s", error->str);
+      g_warning("GConf init failed:\n  %s", error->message);
       /* These next two lines would be important if we weren't going to
          exit immediately */
-      gconf_error_destroy(error);
+      g_error_free(error);
       error = NULL;
       return 1;
     }
@@ -75,26 +76,16 @@ main(int argc, char** argv)
 
   gconf_client_add_dir(client, "/apps/basic-gconf-app", GCONF_CLIENT_PRELOAD_NONE, NULL);
 
-  /* The main() function takes over the floating object; the code that
-     "owns" the object should do this, as with any Gtk object.
-     Read about refcounting and destruction at developer.gnome.org/doc/GGAD/ */
-  gtk_object_ref(GTK_OBJECT(client));
-  gtk_object_sink(GTK_OBJECT(client));
-
   main_window = create_main_window(client);
   
   gtk_widget_show_all(main_window);
   
   gtk_main();
 
-  /* Shut down the client cleanly. Note the destroy rather than unref,
-     so the shutdown occurs even if there are outstanding references.
-     If your program isn't exiting you probably want to just plain unref()
-     Read about refcounting and destruction at developer.gnome.org/doc/GGAD/ */
-  gtk_object_destroy(GTK_OBJECT(client));
-  /* Now avoid leaking memory (not that this matters since the program
-     is exiting... */
-  gtk_object_unref(GTK_OBJECT(client));
+  /* This ensures we cleanly detach from the GConf server (assuming
+   * we hold the last reference)
+   */
+  g_object_unref(G_OBJECT(client));
   
   return 0;
 }
@@ -123,9 +114,7 @@ configurable_widget_destroy_callback(GtkWidget* widget, gpointer data)
 static void
 configurable_widget_config_notify(GConfClient* client,
                                   guint cnxn_id,
-                                  const gchar* key,
-                                  GConfValue* value,
-                                  gboolean is_default,
+                                  GConfEntry *entry,
                                   gpointer user_data)
 {
   GtkWidget* label = user_data;
@@ -136,13 +125,14 @@ configurable_widget_config_notify(GConfClient* client,
   /* Note that value can be NULL (unset) or it can have
      the wrong type! */
   
-  if (value == NULL)
+  if (entry->value == NULL)
     {
       gtk_label_set_text(GTK_LABEL(label), "");
     }
-  else if (value->type == GCONF_VALUE_STRING)
+  else if (entry->value->type == GCONF_VALUE_STRING)
     {
-      gtk_label_set_text(GTK_LABEL(label), gconf_value_string(value));
+      gtk_label_set_text(GTK_LABEL(label),
+                         gconf_value_get_string(entry->value));
     }
   else
     {
@@ -186,7 +176,7 @@ create_configurable_widget(GConfClient* client, const gchar* config_key)
   gtk_object_set_data(GTK_OBJECT(label), "client", client);
 
   gtk_signal_connect(GTK_OBJECT(label), "destroy",
-                     configurable_widget_destroy_callback,
+                     GTK_SIGNAL_FUNC(configurable_widget_destroy_callback),
                      NULL);
   
   return frame;
@@ -336,7 +326,7 @@ prefs_dialog_apply(GtkWidget* dialog)
 
   if (revert_cs == NULL)
     {
-      revert_cs = gconf_client_create_change_set_from_current(client,
+      revert_cs = gconf_client_change_set_from_current(client,
                                                               NULL,
                                                               "/apps/basic-gconf-app/foo",
                                                               "/apps/basic-gconf-app/bar",
@@ -384,26 +374,26 @@ update_entry(GtkWidget* dialog, GConfChangeSet* cs, const gchar* config_key)
           GConfValue* def;
 
           def = gconf_client_get_default_from_schema(client,
-                                                   config_key,
-                                                   NULL);
+                                                     config_key,
+                                                     NULL);
 
           if (def)
             {
               if (def->type == GCONF_VALUE_STRING)
                 {
-                  gtk_entry_set_text(GTK_ENTRY(entry), gconf_value_string(def));
+                  gtk_entry_set_text(GTK_ENTRY(entry), gconf_value_get_string(def));
                 }
               else
                 g_warning("Wrong type for default value of %s", config_key);
 
-              gconf_value_destroy(def);
+              gconf_value_free(def);
             }
           else
             gtk_entry_set_text(GTK_ENTRY(entry), "");
         }
       else if (value->type == GCONF_VALUE_STRING)
         {
-          gtk_entry_set_text(GTK_ENTRY(entry), gconf_value_string(value));
+          gtk_entry_set_text(GTK_ENTRY(entry), gconf_value_get_string(value));
         }
       else
         {
@@ -494,29 +484,29 @@ create_config_entry(GtkWidget* prefs_dialog, GConfClient* client, const gchar* c
   frame = gtk_frame_new(config_key);
 
   entry = gtk_entry_new();
-
+  
   gtk_container_add(GTK_CONTAINER(frame), entry);
   
   initial = gconf_client_get(client, config_key, NULL);
 
   if (initial != NULL && initial->type == GCONF_VALUE_STRING)
     {
-      const gchar* str = gconf_value_string(initial);
+      const gchar* str = gconf_value_get_string(initial);
       gtk_entry_set_text(GTK_ENTRY(entry), str);
     }
 
   if (initial)
-    gconf_value_destroy(initial);
+    gconf_value_free(initial);
   
   gtk_object_set_data(GTK_OBJECT(entry), "client", client);
   gtk_object_set_data(GTK_OBJECT(entry), "key", g_strdup(config_key));
 
   gtk_signal_connect(GTK_OBJECT(entry), "destroy",
-                     config_entry_destroy_callback,
+                     GTK_SIGNAL_FUNC(config_entry_destroy_callback),
                      NULL);
 
   gtk_signal_connect(GTK_OBJECT(entry), "changed",
-                     config_entry_changed_callback,
+                     GTK_SIGNAL_FUNC(config_entry_changed_callback),
                      prefs_dialog);
 
   /* A dubious hack; set the entry as object data using its
@@ -524,6 +514,11 @@ create_config_entry(GtkWidget* prefs_dialog, GConfClient* client, const gchar* c
      revert code */
   gtk_object_set_data(GTK_OBJECT(prefs_dialog),
                       config_key, entry);
+
+  /* Set the entry insensitive if the key it edits isn't writable */
+  gtk_widget_set_sensitive (entry,
+                            gconf_client_key_is_writable (client,
+                                                          config_key, NULL));
   
   return frame;
 }
@@ -576,7 +571,7 @@ prefs_dialog_destroy_callback(GtkWidget* dialog, gpointer data)
   if (revert_cs)
     gconf_change_set_unref(revert_cs);
 
-  gtk_object_unref(GTK_OBJECT(client));
+  g_object_unref(G_OBJECT(client));
 }
 
 static GtkWidget*
@@ -593,7 +588,7 @@ create_prefs_dialog(GtkWidget* parent, GConfClient* client)
   GtkWidget* vbox_inner;
   GtkWidget* entry;
   
-  dialog = gtk_window_new(GTK_WINDOW_DIALOG);
+  dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
   apply = gtk_button_new_with_label("Apply");
   revert = gtk_button_new_with_label("Revert");
@@ -628,7 +623,7 @@ create_prefs_dialog(GtkWidget* parent, GConfClient* client)
   gtk_object_set_data(GTK_OBJECT(dialog), "client", client);
 
   /* Grab a reference */
-  gtk_object_ref(GTK_OBJECT(client));
+  g_object_ref(G_OBJECT(client));
   
   gtk_signal_connect(GTK_OBJECT(dialog), "destroy",
                      GTK_SIGNAL_FUNC(prefs_dialog_destroy_callback),
