@@ -22,8 +22,7 @@
 #include "gconf-internals.h"
 #include "gconf-backend.h"
 #include "gconf-schema.h"
-#include <orb/orbit.h>
-#include <liboaf/liboaf.h>
+#include <bonobo-activation/bonobo-activation.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -287,7 +286,7 @@ gconf_value_from_corba_value(const ConfigValue* value)
 }
 
 void          
-fill_corba_value_from_gconf_value(GConfValue* value, 
+fill_corba_value_from_gconf_value(const GConfValue* value, 
                                    ConfigValue* cv)
 {
   if (value == NULL)
@@ -405,7 +404,7 @@ fill_corba_value_from_gconf_value(GConfValue* value,
 }
 
 ConfigValue*  
-corba_value_from_gconf_value(GConfValue* value)
+corba_value_from_gconf_value(const GConfValue* value)
 {
   ConfigValue* cv;
 
@@ -438,7 +437,8 @@ gconf_object_to_string (CORBA_Object obj,
   
   CORBA_exception_init (&ev);
 
-  ior = CORBA_ORB_object_to_string (oaf_orb_get (), obj, &ev);
+  ior = CORBA_ORB_object_to_string (
+	  bonobo_activation_orb_get (), obj, &ev);
 
   if (ior == NULL)
     {
@@ -511,7 +511,7 @@ gconf_type_from_corba_type(ConfigValueType type)
 }
 
 void          
-fill_corba_schema_from_gconf_schema(GConfSchema* sc, 
+fill_corba_schema_from_gconf_schema(const GConfSchema* sc, 
                                      ConfigSchema* cs)
 {
   cs->value_type = corba_type_from_gconf_type(sc->type);
@@ -546,7 +546,7 @@ fill_corba_schema_from_gconf_schema(GConfSchema* sc,
 }
 
 ConfigSchema* 
-corba_schema_from_gconf_schema(GConfSchema* sc)
+corba_schema_from_gconf_schema(const GConfSchema* sc)
 {
   ConfigSchema* cs;
 
@@ -794,14 +794,12 @@ subst_variables(const gchar* src)
   return retval;
 }
 
-gchar**       
+GSList *
 gconf_load_source_path(const gchar* filename, GError** err)
 {
   FILE* f;
-  GSList* l = NULL;
-  gchar** addresses;
+  GSList *l = NULL;
   gchar buf[512];
-  GSList* tmp;
   guint n;
 
   f = fopen(filename, "r");
@@ -834,25 +832,17 @@ gconf_load_source_path(const gchar* filename, GError** err)
       else if (strncmp("include", s, 7) == 0)
         {
           gchar* unq;
-          gchar** included;
+          GSList* included;
 
           s += 7;
-
+          while (isspace(*s)) s++;
           unq = unquote_string(s);
 
           included = gconf_load_source_path(unq, NULL);
 
           if (included != NULL)
             {
-              gchar** iter = included;
-
-              while (*iter)
-                {
-                  l = g_slist_prepend(l, *iter); /* Note that we won't free *included */
-                  ++iter;
-                }
-
-              g_free(included); /* Only the array, not the contained strings */
+              g_slist_concat(l, included);
             }
         }
       else 
@@ -894,27 +884,8 @@ gconf_load_source_path(const gchar* filename, GError** err)
     return NULL;
 
   n = g_slist_length(l);
-
   g_assert(n > 0);
-  
-  addresses = g_malloc0(sizeof(gchar*) * (n+1));
-
-  addresses[n] = NULL;
-
-  --n;
-  tmp = l;
-
-  while (tmp != NULL)
-    {
-      addresses[n] = tmp->data;
-
-      tmp = g_slist_next(tmp);
-      --n;
-    }
-  
-  g_assert(addresses[0] != NULL); /* since we used malloc0 this detects bad logic */
-
-  return addresses;
+  return l;
 }
 
 /* This should also support concatting filesystem dirs and keys, 
@@ -2166,28 +2137,28 @@ gconf_handle_oaf_exception(CORBA_Environment* ev, GError** err)
       {
         const gchar* id = CORBA_exception_id(ev);
 
-        if (strcmp(id, "IDL:OAF/GeneralError:1.0") == 0)
+        if (strcmp(id, "IDL:Bonobo/GeneralError:1.0") == 0)
           {
-            OAF_GeneralError* ge = CORBA_exception_value(ev);
+            Bonobo_GeneralError* ge = CORBA_exception_value(ev);
 
             if (err)
               *err = gconf_error_new (GCONF_ERROR_OAF_ERROR,
-                                      _("OAF problem description: '%s'"),
+                                      _("bonobo-activation problem description: '%s'"),
                                       ge->description);
           }
-        else if (strcmp (id,"IDL:OAF/ActivationContext/NotListed:1.0" ) == 0)
+        else if (strcmp (id,"IDL:Bonobo/ActivationContext/NotListed:1.0" ) == 0)
           {
             if (err)
               *err = gconf_error_new(GCONF_ERROR_OAF_ERROR, _("attempt to remove not-listed OAF object directory"));
           }
-        else if (strcmp (id,"IDL:OAF/ActivationContext/AlreadyListed:1.0" ) == 0)
+        else if (strcmp (id,"IDL:Bonobo/ActivationContext/AlreadyListed:1.0" ) == 0)
           {
             if (err)
               *err = gconf_error_new(GCONF_ERROR_OAF_ERROR, _("attempt to add already-listed OAF directory")); 
           }
-        else if (strcmp (id,"IDL:OAF/ActivationContext/ParseFailed:1.0") == 0)
+        else if (strcmp (id,"IDL:Bonobo/ActivationContext/ParseFailed:1.0") == 0)
           {
-            OAF_ActivationContext_ParseFailed* pe = CORBA_exception_value(ev);
+            Bonobo_ActivationContext_ParseFailed* pe = CORBA_exception_value(ev);
             
             if (err)
               *err = gconf_error_new(GCONF_ERROR_OAF_ERROR, _("OAF parse error: %s"), pe->description);
@@ -2336,7 +2307,7 @@ gconf_get_lock_or_current_holder (const gchar*  lock_directory,
 
                   CORBA_exception_init(&ev);
                   
-                  orb = oaf_orb_get();
+                  orb = bonobo_activation_orb_get();
 
                   if (orb == NULL)
                     {
@@ -2577,5 +2548,3 @@ gconf_release_lock(GConfLock* lock,
   gconf_lock_destroy(lock);
   return TRUE;
 }
-
-
