@@ -46,8 +46,8 @@ gboolean gconf_file_test   (const gchar* filename, int test);
 gboolean gconf_file_exists (const gchar* filename);
 
 GConfValue*  gconf_value_from_corba_value      (const ConfigValue *value);
-ConfigValue* corba_value_from_gconf_value      (GConfValue        *value);
-void         fill_corba_value_from_gconf_value (GConfValue        *value,
+ConfigValue* corba_value_from_gconf_value      (const GConfValue  *value);
+void         fill_corba_value_from_gconf_value (const GConfValue  *value,
                                                 ConfigValue       *dest);
 ConfigValue* invalid_corba_value               (void);
 
@@ -55,16 +55,16 @@ ConfigValue* invalid_corba_value               (void);
 gchar* gconf_object_to_string (CORBA_Object obj,
                                GError **err);
 
-void          fill_corba_schema_from_gconf_schema (GConfSchema        *sc,
+void          fill_corba_schema_from_gconf_schema (const GConfSchema  *sc,
                                                    ConfigSchema       *dest);
-ConfigSchema* corba_schema_from_gconf_schema      (GConfSchema        *sc);
+ConfigSchema* corba_schema_from_gconf_schema      (const GConfSchema  *sc);
 GConfSchema*  gconf_schema_from_corba_schema      (const ConfigSchema *cs);
 
 const gchar*   gconf_value_type_to_string   (GConfValueType  type);
 GConfValueType gconf_value_type_from_string (const gchar    *str);
 
 
-gchar**       gconf_load_source_path (const gchar* filename, GError** err);
+GSList*       gconf_load_source_path (const gchar* filename, GError** err);
 
 /* shouldn't be used in applications (although implemented in gconf.c) */
 
@@ -104,10 +104,6 @@ gboolean      gconf_key_check(const gchar* key, GError** err);
  * If these were public they'd be in gconf-value.h
  */
 
-/* doesn't work on complicated types (only string, int, bool, float) */
-GConfValue* gconf_value_new_from_string      (GConfValueType type,
-                                              const gchar* str,
-                                              GError** err);
 /* for the complicated types */
 GConfValue* gconf_value_new_list_from_string (GConfValueType list_type,
                                               const gchar* str,
@@ -142,13 +138,12 @@ gchar* gconf_quote_percents (const gchar* src);
  */
 
 GConfValue* gconf_value_list_from_primitive_list (GConfValueType  list_type,
-                                                  GSList         *list,
-                                                  GError        **err);
+                                                  GSList         *list);
 GConfValue* gconf_value_pair_from_primitive_pair (GConfValueType  car_type,
                                                   GConfValueType  cdr_type,
                                                   gconstpointer   address_of_car,
-                                                  gconstpointer   address_of_cdr,
-                                                  GError        **err);
+                                                  gconstpointer   address_of_cdr);
+
 
 GSList*  gconf_value_list_to_primitive_list_destructive (GConfValue      *val,
                                                          GConfValueType   list_type,
@@ -180,7 +175,8 @@ gboolean   gconf_release_lock (GConfLock    *lock,
 GConfLock* gconf_get_lock_or_current_holder (const gchar  *lock_directory,
                                              ConfigServer *current_server,
                                              GError      **err);
-ConfigServer gconf_get_current_lock_holder  (const gchar *lock_directory);
+
+
 
 GError*  gconf_error_new  (GConfError en,
                            const gchar* format, ...) G_GNUC_PRINTF (2, 3);
@@ -192,23 +188,6 @@ void     gconf_set_error  (GError** err,
 /* merge two errors into a single message */
 GError*  gconf_compose_errors (GError* err1, GError* err2);
 
-CORBA_ORB gconf_orb_get (void);
-
-ConfigServer gconf_activate_server (gboolean  start_if_not_found,
-                                    GError  **error);
-
-char*     gconf_get_lock_dir (void);
-char*     gconf_get_daemon_dir (void);
-
-gboolean gconf_schema_validate (GConfSchema *sc,
-                                GError     **err);
-gboolean gconf_value_validate  (GConfValue *value,
-                                GError    **err);
-
-gboolean g_utf8_validate (const gchar  *str,
-                          gssize        max_len,    
-                          const gchar **end);
-
 #ifdef ENABLE_NLS
 #    include <libintl.h>
 #    include <config.h>
@@ -227,6 +206,35 @@ gboolean g_utf8_validate (const gchar  *str,
 #    define N_(String) (String)
 #endif
 
+static inline gboolean
+gconf_CORBA_Object_equal (gconstpointer a, gconstpointer b)
+{
+  CORBA_Environment ev;
+  CORBA_Object _obj_a = (gpointer)a;
+  CORBA_Object _obj_b = (gpointer)b;
+  gboolean retval;
+
+  CORBA_exception_init (&ev);
+  retval = CORBA_Object_is_equivalent(_obj_a, _obj_b, &ev);
+  CORBA_exception_free (&ev);
+
+  return retval;
+}
+
+static inline guint
+gconf_CORBA_Object_hash(gconstpointer key)
+{
+  CORBA_Environment ev;
+  CORBA_Object _obj = (gpointer)key;
+  CORBA_unsigned_long retval;
+
+  CORBA_exception_init (&ev);
+  retval = CORBA_Object_hash(_obj, G_MAXUINT, &ev);
+  CORBA_exception_free (&ev);
+
+  return retval;
+}
+
 #endif /* GCONF_ENABLE_INTERNALS */
 
 #endif /* GCONF_GCONF_INTERNALS_H */
