@@ -96,7 +96,7 @@ source_is_writable(GConfSource* source, const gchar* key, GError** err)
     return FALSE;
   else if ((source->flags & GCONF_SOURCE_ALL_WRITEABLE) != 0)
     return TRUE;
-  else if (source->backend->vtable->writable != NULL &&
+  else if ((source->backend->vtable->writable != NULL) &&
            (*source->backend->vtable->writable)(source, key, err))
     return TRUE;
   else
@@ -150,7 +150,7 @@ gconf_source_query_metainfo      (GConfSource* source,
 static gboolean
 gconf_source_set_value        (GConfSource* source,
                                const gchar* key,
-                               GConfValue* value,
+                               const GConfValue* value,
                                GError** err)
 {
   g_return_val_if_fail(source != NULL, FALSE);
@@ -294,7 +294,7 @@ gconf_source_sync_all         (GConfSource* source, GError** err)
  */
 
 GConfSources* 
-gconf_sources_new_from_addresses(const gchar** addresses, GError** err)
+gconf_sources_new_from_addresses(GSList * addresses, GError** err)
 {
   GConfSources* sources;
 
@@ -302,12 +302,12 @@ gconf_sources_new_from_addresses(const gchar** addresses, GError** err)
   
   sources = g_new0(GConfSources, 1);
 
-  while (*addresses != NULL)
+  while (addresses != NULL)
     {
       GConfSource* source;
       GError* error = NULL;
       
-      source = gconf_resolve_address(*addresses, &error);
+      source = gconf_resolve_address((const gchar*)addresses->data, &error);
 
       if (source != NULL)
         {
@@ -318,12 +318,12 @@ gconf_sources_new_from_addresses(const gchar** addresses, GError** err)
         {
           g_assert(error != NULL);
           gconf_log(GCL_WARNING, _("Failed to load source `%s': %s"),
-                    *addresses, error->message);
+                    (const gchar*)addresses->data, error->message);
           
           g_error_free(error);
         }
           
-      ++addresses;
+      addresses = g_slist_next(addresses);
     }
 
   sources->sources = g_list_reverse(sources->sources);
@@ -547,7 +547,7 @@ gconf_sources_query_value (GConfSources* sources,
 void
 gconf_sources_set_value   (GConfSources* sources,
                            const gchar* key,
-                           GConfValue* value,
+                           const GConfValue* value,
                            GError** err)
 {
   GList* tmp;
@@ -605,7 +605,7 @@ gconf_sources_set_value   (GConfSources* sources,
   g_set_error (err,
                GCONF_ERROR,
                GCONF_ERROR_NO_WRITABLE_DATABASE,
-               _("Unable to store a value at key '%s', as the configuration server has no writeable databases. There are two common causes of this problem: 1) your configuration path file doesn't contain any databases or wasn't found or 2) somehow we mistakenly created two gconfd processes. If you have two gconfd processes (or had two at the time the second was launched), logging out, killing all copies of gconfd, and logging back in may help. Perhaps the problem is that you attempted to use GConf from two machines at once, and ORBit still has its default configuration that prevents remote CORBA connections? As always, check the user.* syslog for details on problems gconfd encountered."),
+               _("Unable to store a value at key '%s', as the configuration server has no writeable databases. There are two common causes of this problem: 1) your configuration path file doesn't contain any databases or wasn't found or 2) bonobo-activation mistakenly created two gconfd processes. If you have two gconfd processes (or had two at the time the second was launched), then it's an bonobo-activation bug, not a GConf issue. Logging out, killing bonobo-activation-server and gconfd, and logging back in may help. As always, check the user.* syslog for details on problems gconfd encountered."),
                key);
 }
 
