@@ -32,7 +32,7 @@
 #include <sys/wait.h>
 #include <sys/time.h>
 #include <unistd.h>
-#include <liboaf/liboaf.h>
+#include <bonobo-activation/bonobo-activation.h>
 
 /* Returns TRUE if there was an error, frees exception, sets err */
 static gboolean gconf_handle_corba_exception(CORBA_Environment* ev, GError** err);
@@ -217,8 +217,8 @@ gconf_engine_set_database (GConfEngine *conf,
   conf->database = db;
 
   if (engines_by_db == NULL)
-    engines_by_db = g_hash_table_new ((GHashFunc) g_CORBA_Object_hash,
-                                      (GCompareFunc) g_CORBA_Object_equal);
+    engines_by_db = g_hash_table_new ((GHashFunc) gconf_CORBA_Object_hash,
+                                      (GCompareFunc) gconf_CORBA_Object_equal);
   
   g_hash_table_insert (engines_by_db, conf->database, conf);  
 }
@@ -974,7 +974,7 @@ gconf_engine_get_default_from_schema (GConfEngine* conf,
 
 gboolean
 gconf_engine_set (GConfEngine* conf, const gchar* key,
-                  GConfValue* value, GError** err)
+                  const GConfValue* value, GError** err)
 {
   ConfigValue* cv;
   CORBA_Environment ev;
@@ -1845,15 +1845,15 @@ static ConfigServer
 try_to_contact_server(gboolean start_if_not_found, GError** err)
 {
   CORBA_Environment ev;
-  OAF_ActivationFlags flags;
+  Bonobo_ActivationFlags flags;
   
   CORBA_exception_init(&ev);
 
   flags = 0;
   if (!start_if_not_found)
-    flags |= OAF_FLAG_EXISTING_ONLY;
+    flags |= Bonobo_ACTIVATION_FLAG_EXISTING_ONLY;
   
-  server = oaf_activate_from_id ("OAFAID:["IID"]", flags, NULL, &ev);
+  server = bonobo_activation_activate_from_id ("OAFAID:["IID"]", flags, NULL, &ev);
 
   /* So try to ping server, by adding ourselves as a client */
   if (!CORBA_Object_is_nil (server, &ev))
@@ -1884,7 +1884,7 @@ try_to_contact_server(gboolean start_if_not_found, GError** err)
 
       if (err && *err == NULL)
         *err = gconf_error_new(GCONF_ERROR_NO_SERVER,
-                               _("Error contacting configuration server: OAF returned nil from oaf_activate_from_id() and did not set an exception explaining the problem. This is a bug in the OAF package; something went wrong in OAF, and no error was reported. This is not a bug in the GConf package. Do not report a GConf bug unless you have information indicating what went wrong with OAF that was caused by GConf."));
+                               _("Error contacting configuration server: bonobo-activation returned nil from bonobo_activation_activate_from_id() and did not set an exception explaining the problem. This is a bug in the bonobo-activation package; something went wrong in bonobo-activation, and no error was reported. This is not a bug in the GConf package. Do not report a GConf bug unless you have information indicating what went wrong with bonobo-activation that was caused by GConf."));
     }
 
 #ifdef GCONF_ENABLE_DEBUG      
@@ -2129,7 +2129,7 @@ gconf_postinit(gpointer app, gpointer mod_info)
   if (listener == CORBA_OBJECT_NIL)
     {
       CORBA_Environment ev;
-      PortableServer_ObjectId objid = {0, sizeof("ConfigListener"), "ConfigListener"};
+      PortableServer_ObjectId* objid;
       PortableServer_POA poa;
 
       CORBA_exception_init(&ev);
@@ -2137,7 +2137,8 @@ gconf_postinit(gpointer app, gpointer mod_info)
       
       g_assert (ev._major == CORBA_NO_EXCEPTION);
 
-      poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(oaf_orb_get(), "RootPOA", &ev);
+      poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(
+	      bonobo_activation_orb_get(), "RootPOA", &ev);
 
       g_assert (ev._major == CORBA_NO_EXCEPTION);
 
@@ -2145,8 +2146,7 @@ gconf_postinit(gpointer app, gpointer mod_info)
 
       g_assert (ev._major == CORBA_NO_EXCEPTION);
 
-      PortableServer_POA_activate_object_with_id(poa,
-                                                 &objid, &poa_listener_servant, &ev);
+      objid = PortableServer_POA_activate_object(poa, &poa_listener_servant, &ev);
 
       g_assert (ev._major == CORBA_NO_EXCEPTION);
       
@@ -2180,13 +2180,13 @@ gconf_init           (int argc, char **argv, GError** err)
 
   gconf_preinit(NULL, NULL);
 
-  if (!oaf_is_initialized())
+  if (!bonobo_activation_is_initialized())
     {
-      orb = oaf_init(argc, argv);
+      orb = bonobo_activation_init(argc, argv);
     }
   else
     {
-      orb = oaf_orb_get();
+      orb = bonobo_activation_orb_get();
     }
       
   gconf_postinit(NULL, NULL);
@@ -2932,7 +2932,7 @@ gconf_engine_set_bool    (GConfEngine* conf, const gchar* key,
 
 gboolean
 gconf_engine_set_schema  (GConfEngine* conf, const gchar* key,
-                    GConfSchema* val, GError** err)
+                    const GConfSchema* val, GError** err)
 {
   GConfValue* gval;
 
