@@ -32,11 +32,10 @@
 #include "gconf-listeners.h"
 #include "gconf-locale.h"
 #include "gconf-schema.h"
-#include "gconf-glib-private.h"
 #include "gconf.h"
 #include "gconfd.h"
 #include "gconf-database.h"
-#include <orb/orbit.h>
+#include <orbit/orbit.h>
 
 #include "GConf.h"
 
@@ -52,6 +51,7 @@
 #include <ctype.h>
 #include <syslog.h>
 #include <time.h>
+#include <bonobo-activation/bonobo-activation.h>
 
 /* This makes hash table safer when debugging */
 #ifndef GCONF_ENABLE_DEBUG
@@ -258,7 +258,7 @@ gconfd_shutdown(PortableServer_Servant servant, CORBA_Environment *ev)
 static void
 gconf_server_load_sources(void)
 {
-  gchar** addresses;
+  GSList* addresses;
   GList* tmp;
   gboolean have_writable = FALSE;
   gchar* conffile;
@@ -288,13 +288,9 @@ gconf_server_load_sources(void)
   if (addresses == NULL)
     {      
       /* Try using the default address xml:readwrite:$(HOME)/.gconf */
-      addresses = g_new0(gchar*, 2);
+      addresses = g_slist_append(addresses, g_strconcat("xml:readwrite:", g_get_home_dir(), "/.gconf", NULL));
 
-      addresses[0] = g_strconcat("xml:readwrite:", g_get_home_dir(), "/.gconf", NULL);
-
-      addresses[1] = NULL;
-      
-      gconf_log(GCL_DEBUG, _("No configuration files found, trying to use the default config source `%s'"), addresses[0]);
+      gconf_log(GCL_INFO, _("No configuration files found, trying to use the default config source `%s'"), (char *)addresses->data);
     }
   
   if (addresses == NULL)
@@ -302,18 +298,16 @@ gconf_server_load_sources(void)
       /* We want to stay alive but do nothing, because otherwise every
          request would result in another failed gconfd being spawned.  
       */
-      const gchar* empty_addr[] = { NULL };
       gconf_log(GCL_ERR, _("No configuration sources in the source path, configuration won't be saved; edit "GCONF_CONFDIR"/path"));
       /* don't request error since there aren't any addresses */
-      sources = gconf_sources_new_from_addresses(empty_addr, NULL);
+      sources = gconf_sources_new_from_addresses(NULL, NULL);
 
       /* Install the sources as the default database */
       set_default_database (gconf_database_new(sources));
     }
   else
     {
-      sources = gconf_sources_new_from_addresses((const gchar**)addresses,
-                                                 &error);
+      sources = gconf_sources_new_from_addresses(addresses, &error);
 
       if (error != NULL)
         {
@@ -324,7 +318,7 @@ gconf_server_load_sources(void)
           error = NULL;
         }
       
-      g_free(addresses);
+      g_slist_free(addresses);
 
       g_assert(sources != NULL);
 
@@ -475,35 +469,21 @@ main(int argc, char** argv)
   const gchar* username;
   guint len;
   gchar* ior;
+  Bonobo_RegistrationResult result;
   int exit_code = 0;
   GError *err;
   char *lock_dir;
   char *gconfd_dir;
-  int dev_null_fd;
-  int write_byte_fd;
-  
-  /* Now this is an argument parser */
-  if (argc > 1)
-    write_byte_fd = atoi (argv[1]);
-  else
-    write_byte_fd = -1;
+  ConfigServer other_server;
   
   chdir ("/");
 
   /* This is so we don't prevent unmounting of devices. We divert
    * all messages to syslog
    */
-
-  if (!g_getenv ("GCONF_DEBUG_OUTPUT"))
-    {
-      dev_null_fd = open ("/dev/null", O_RDWR);
-      if (dev_null_fd >= 0)
-        {
-	  dup2 (dev_null_fd, 0);
-	  dup2 (dev_null_fd, 1);
-	  dup2 (dev_null_fd, 2);
-	}
-    }
+  close (0);
+  close (1);
+  close (2);
   
   umask (022);
   
@@ -548,9 +528,15 @@ main(int argc, char** argv)
 
   CORBA_exception_init(&ev);
 
+  if (!bonobo_activation_init(argc, argv))
+    {
+      gconf_log(GCL_ERR, _("Failed to init Object Activation Framework: please mail bug report to bonobo-activation maintainers"));
+      exit(1);
+    }
+
   init_databases ();
 
-  orb = gconf_orb_get();
+  orb = bonobo_activation_orb_get();
   
   POA_ConfigServer__init(&poa_server_servant, &ev);
   
@@ -573,52 +559,90 @@ main(int argc, char** argv)
   gconf_set_daemon_ior (ior);
   CORBA_free (ior);
 
-  gconfd_dir = gconf_get_daemon_dir ();
-  lock_dir = gconf_get_lock_dir ();
+  gconfd_dir = g_strconcat (g_get_home_dir (), "/.gconfd", NULL);
+  lock_dir = g_strconcat (gconfd_dir, "/lock", NULL);
 
   if (mkdir (gconfd_dir, 0700) < 0 && errno != EEXIST)
     gconf_log (GCL_WARNING, _("Failed to create %s: %s"),
                gconfd_dir, g_strerror (errno));
   
-  
   err = NULL;
-  daemon_lock = gconf_get_lock (lock_dir, &err);
+  daemon_lock = gconf_get_lock_or_current_holder (lock_dir,
+                                                  &other_server,
+                                                  &err);
 
-  if (daemon_lock != NULL)
-    {
-      /* This loads backends and so on. It needs to be done before
-       * we can handle any requests, so before we hit the
-       * main loop. if daemon_lock == NULL we won't hit the
-       * main loop.
-       */
-      gconf_server_load_sources ();
-    }
-  
-  /* notify caller that we're done either getting the lock
-   * or not getting it
-   */
-  if (write_byte_fd >= 0)
-    {
-      char buf[1] = { 'g' };
-      if (write (write_byte_fd, buf, 1) != 1)
-        {
-          gconf_log (GCL_ERR, _("Failed to write byte to pipe fd %d so client program may hang: %s"), write_byte_fd, g_strerror (errno));
-        }
-
-      close (write_byte_fd);
-    }
-  
   if (daemon_lock == NULL)
     {
       g_assert (err);
-
-      gconf_log (GCL_WARNING, _("Failed to get lock for daemon, exiting: %s"),
+      
+      /* Bad hack alert - register the current lockholder with bonobo-activation-server,
+       * since bonobo-activation-server seems to have forgotten about us.
+       */
+      gconf_log (GCL_WARNING, _("Failed to get lock for daemon: %s"),
                  err->message);
       g_error_free (err);
 
+      if (other_server != CORBA_OBJECT_NIL)
+        {
+          gconf_log (GCL_WARNING, _("Registering existing server with bonobo-activation-server, since we seem to have been leaked"));
+          
+          result = bonobo_activation_active_server_register (IID, other_server);
+          
+          if (result != Bonobo_ACTIVATION_REG_SUCCESS)
+            {
+              switch (result)
+                {
+                case Bonobo_ACTIVATION_REG_NOT_LISTED:
+                  gconf_log(GCL_ERR, _("OAF doesn't know about our IID; indicates broken installation; can't register existing server."));
+                  break;
+                  
+                case Bonobo_ACTIVATION_REG_ALREADY_ACTIVE:
+                  gconf_log(GCL_ERR, _("Another gconfd already registered with OAF, so we can't register the existing server"));
+                  break;
+                  
+                case Bonobo_ACTIVATION_REG_ERROR:
+                default:
+                  gconf_log(GCL_ERR, _("Unknown error registering existing gconfd with OAF; exiting"));
+                  break;
+                }
+            }
+
+          {
+            CORBA_Environment localev;
+            CORBA_exception_init (&localev);
+            CORBA_Object_release (server, &localev);
+            CORBA_exception_free (&localev);
+          }
+        }
+
+      return 1;
+    }
+  
+  /* Needs to be done right before registration,
+     after setting up the POA etc. */
+  gconf_server_load_sources();
+  
+  result = bonobo_activation_active_server_register(IID, server);
+
+  if (result != Bonobo_ACTIVATION_REG_SUCCESS)
+    {
+      switch (result)
+        {
+        case Bonobo_ACTIVATION_REG_NOT_LISTED:
+          gconf_log(GCL_ERR, _("bonobo-activation doesn't know about our IID; indicates broken installation; can't register; exiting\n"));
+          break;
+          
+        case Bonobo_ACTIVATION_REG_ALREADY_ACTIVE:
+          gconf_log(GCL_ERR, _("Another gconfd already registered with bonobo-activation; exiting\n"));
+          break;
+
+        case Bonobo_ACTIVATION_REG_ERROR:
+        default:
+          gconf_log(GCL_ERR, _("Unknown error registering gconfd with bonobo-activation; exiting\n"));
+          break;
+        }
       enter_shutdown ();
       shutdown_databases ();
-      
       return 1;
     }
 
@@ -644,9 +668,13 @@ main(int argc, char** argv)
 
   gconfd_locale_cache_drop ();
 
-  /* Now we can release the lock */
+  /* Now we can unregister with bonobo-activation everything is fixed up. */  
 
-  server = CORBA_OBJECT_NIL;
+  if (server != CORBA_OBJECT_NIL)
+    {
+      bonobo_activation_active_server_unregister ("", server);
+      server = CORBA_OBJECT_NIL;
+    }
 
   if (daemon_lock)
     {
@@ -654,7 +682,7 @@ main(int argc, char** argv)
       gconf_release_lock (daemon_lock, &err);
       if (err != NULL)
         {
-          gconf_log (GCL_WARNING, _("Error releasing lockfile: %s"),
+          gconf_log (GCL_WARNING, _("Failed to release lockfile: %s"),
                      err->message);
           g_error_free (err);
         }
@@ -727,7 +755,7 @@ gconf_main(void)
 #ifdef GCONF_ENABLE_DEBUG
       gulong timeout_len = 1000*60*1; /* 1 sec * 60 s/min * 1 min */
 #else
-      gulong timeout_len = 1000*60*15; /* 1 sec * 60 s/min * 2 min */
+      gulong timeout_len = 1000*60*15; /* 1 sec * 60 s/min * 15 min */
 #endif
       
       g_assert(timeout_id == 0);
@@ -844,11 +872,11 @@ obtain_database (const gchar *address,
 {
   
   GConfSources* sources;
-  const gchar* addresses[] = { NULL, NULL };
+  GSList* addresses = NULL;
   GError* error = NULL;
   GConfDatabase *db;
 
-  addresses[0] = address;
+  g_slist_append(addresses, g_strdup(address));
   db = lookup_database (address);
 
   if (db)
@@ -1630,9 +1658,8 @@ restore_client (const gchar *ior)
   
   CORBA_exception_init (&ev);
   
-  cl = CORBA_ORB_string_to_object (gconf_orb_get (),
-                                   (gchar*)ior,
-                                   &ev);
+  cl = CORBA_ORB_string_to_object (
+	  bonobo_activation_orb_get (), (gchar*)ior, &ev);
 
   CORBA_exception_free (&ev);
   
@@ -1679,9 +1706,8 @@ restore_listener (GConfDatabase* db,
   
   CORBA_exception_init (&ev);
   
-  cl = CORBA_ORB_string_to_object (gconf_orb_get (),
-                                   lle->ior,
-                                   &ev);
+  cl = CORBA_ORB_string_to_object (
+	  bonobo_activation_orb_get (), lle->ior, &ev);
 
   CORBA_exception_free (&ev);
   
@@ -2095,8 +2121,8 @@ add_client (const ConfigListener client)
   gconfd_need_log_cleanup ();
   
   if (client_table == NULL)
-    client_table = g_hash_table_new ((GHashFunc) g_CORBA_Object_hash,
-                                     (GCompareFunc) g_CORBA_Object_equal);
+    client_table = g_hash_table_new ((GHashFunc) gconf_CORBA_Object_hash,
+                                     (GCompareFunc) gconf_CORBA_Object_equal);
 
   if (g_hash_table_lookup (client_table, client))
     {
