@@ -21,6 +21,7 @@
 #include "gconf-internals.h"
 #include <stdio.h>
 #include <unistd.h>
+#include <string.h>
 #include <popt.h>
 #include <libxml/tree.h>
 #include <libxml/parser.h>
@@ -47,7 +48,7 @@ static char* short_desc = NULL;
 static char* long_desc = NULL;
 static char* owner = NULL;
 static char* schema_file = NULL;
-static char* config_source = NULL;
+static const char* config_source = NULL;
 static int use_local_source = FALSE;
 static int makefile_install_mode = FALSE;
 static int break_key_mode = FALSE;
@@ -56,7 +57,6 @@ static int short_docs_mode = FALSE;
 static int long_docs_mode = FALSE;
 static int schema_name_mode = FALSE;
 static int associate_schema_mode = FALSE;
-static int default_source_mode = FALSE;
 
 struct poptOption options[] = {
   { 
@@ -321,15 +321,6 @@ struct poptOption options[] = {
     N_("Specify the schema name followed by the key to apply the schema name to"),
     NULL
   },
-  {
-    "get-default-source",
-    '\0',
-    POPT_ARG_NONE,
-    &default_source_mode,
-    0,
-    N_("Get the name of the default source"),
-    NULL
-  },
   {
     NULL,
     '\0',
@@ -360,7 +351,6 @@ static int do_short_docs (GConfEngine *conf, const gchar **args);
 static int do_long_docs (GConfEngine *conf, const gchar **args);
 static int do_get_schema_name (GConfEngine *conf, const gchar **args);
 static int do_associate_schema (GConfEngine *conf, const gchar **args);
-static int do_get_default_source (GConfEngine *conf, const gchar **args);
 
 int 
 main (int argc, char** argv)
@@ -369,8 +359,11 @@ main (int argc, char** argv)
   poptContext ctx;
   gint nextopt;
   GError* err = NULL;
+
+  LIBXML_TEST_VERSION;
+  xmlKeepBlanksDefault(1);
   
-  ctx = poptGetContext("gconftool", argc, argv, options, 0);
+  ctx = poptGetContext("gconftool", argc, (const char **) argv, options, 0);
 
   poptReadDefaultConfig(ctx, TRUE);
 
@@ -537,16 +530,6 @@ main (int argc, char** argv)
       else 
         return 2;
     }
-
-  /* Before creating engine */
-  if (default_source_mode)
-    {
-      const gchar** args = poptGetArgs(ctx);
-      if (do_get_default_source (conf, args)  == 1)
-        return 1;
-      else
-        return 0;
-    }
   
   if (makefile_install_mode)
     {
@@ -566,11 +549,19 @@ main (int argc, char** argv)
           /* Properly set, but set to nothing (use default source) */
           config_source = NULL;
         }
+      
+      if (gconf_ping_daemon())
+        {
+          /* Eventually you should be able to run gconfd as long as
+             you're installing to a different database from the one
+             it's using, but I don't trust the locking right now. */
+          fprintf(stderr, _("Shouldn't run gconfd while installing new schema files.\nUse gconftool --shutdown to shut down the daemon, most safely while no applications are running\n(though things theoretically work if apps are running).\n"));
+          return 1;
+        }
 
+      /* Race condition! gconfd could start up. But we do have locking
+         as a second line of defense. */
       use_local_source = TRUE;
-
-      /* shut down daemon, this is a race condition, but will usually work. */
-      gconf_shutdown_daemon (NULL);
     }
   
   if (config_source == NULL)
@@ -1726,7 +1717,7 @@ extract_global_info(xmlNodePtr node,
   xmlNodePtr iter;
   char* default_value = NULL;
       
-  iter = node->childs;
+  iter = node->xmlChildrenNode;
 
   while (iter != NULL)
     {
@@ -1931,7 +1922,7 @@ process_locale_info(xmlNodePtr node, SchemaInfo* info)
 
 
   /* Locale-specific info */
-  iter = node->childs;
+  iter = node->xmlChildrenNode;
   
   while (iter != NULL)
     {
@@ -2085,7 +2076,7 @@ process_schema(GConfEngine* conf, xmlNodePtr node)
       return 1;
     }
   
-  iter = node->childs;
+  iter = node->xmlChildrenNode;
 
   while (iter != NULL)
     {
@@ -2147,7 +2138,7 @@ process_schema_list(GConfEngine* conf, xmlNodePtr node)
 {
   xmlNodePtr iter;
 
-  iter = node->childs;
+  iter = node->xmlChildrenNode;
 
   while (iter != NULL)
     {
@@ -2181,14 +2172,14 @@ do_load_schema_file(GConfEngine* conf, const gchar* file)
       return 1;
     }
 
-  if (doc->root == NULL)
+  if (doc->xmlRootNode == NULL)
     {
       fprintf(stderr, _("Document `%s' is empty?\n"),
               file);
       return 1;
     }
 
-  iter = doc->root;
+  iter = doc->xmlRootNode;
   while (iter != NULL) 
     {
       if (iter->type == XML_ELEMENT_NODE)
@@ -2213,7 +2204,7 @@ do_load_schema_file(GConfEngine* conf, const gchar* file)
       return 1;
     }
 
-  iter = iter->childs;
+  iter = iter->xmlChildrenNode;
 
   while (iter != NULL)
     {
@@ -2509,36 +2500,3 @@ do_break_directory(GConfEngine* conf, const gchar** args)
 
   return 0;
 }
-
-static int
-do_get_default_source(GConfEngine* conf, const gchar** args)
-{
-  gchar *source;
-  gchar buf[512];
-  FILE *f;
-
-  /* Try with $sysconfdir/gconf/schema-install-source */
-  f = fopen(GCONF_ETCDIR"/schema-install-source", "r");
-
-  if (f != NULL)
-    {
-      source = fgets(buf, 512, f);
-      fclose(f);  
-      if (source)
-	{
-	  g_strchomp(source);
-	  if (*source != '\0')
-	    {
-	      printf("%s\n", source);
-	      return 0;
-	    }
-	}
-    }
-
-  /* Use default database */
-  source = g_strconcat("xml::", GCONF_ETCDIR, "/gconf.xml.defaults", NULL);
-  printf("%s\n", source);
-  g_free(source);
-
-  return 0;
-}
